@@ -5,7 +5,7 @@ docs.  In setup.py in particular, we exec this file, so it cannot import nipy
 
 # nipype version information
 # Remove -dev for release
-__version__ = "1.4.0"
+__version__ = "1.4.1"
 
 
 def get_nipype_gitversion():
@@ -155,11 +155,28 @@ REQUIRES = [
 # https://github.com/nipy/nipype/pull/2961#issuecomment-512035484
 REQUIRES += ["neurdflib"]
 
-TESTS_REQUIRES = ["codecov", "coverage<5", "mock", "pytest", "pytest-cov", "pytest-env"]
+TESTS_REQUIRES = [
+    "codecov",
+    "coverage<5",
+    "mock",
+    "pytest",
+    "pytest-cov",
+    "pytest-env",
+    "pytest-timeout",
+]
 
 EXTRA_REQUIRES = {
     "data": ["datalad"],
-    "doc": ["Sphinx>=1.4", "numpydoc", "matplotlib", "pydotplus", "pydot>=1.2.3"],
+    "doc": [
+        "dipy",
+        "ipython",
+        "matplotlib",
+        "nbsphinx",
+        "sphinx-argparse",
+        "sphinx>=2.1.2",
+        "sphinxcontrib-apidoc",
+        "sphinxcontrib-napoleon",
+    ],
     "duecredit": ["duecredit"],
     "nipy": ["nitime", "nilearn<0.5.0", "dipy", "nipy", "matplotlib"],
     "profiler": ["psutil>=5.0"],
