@@ -9,11 +9,12 @@ from nipype.interfaces.fsl import check_fsl, no_fsl
 
 import pytest
 
+
 @pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
 def test_fslversion():
     ver = fsl.Info.version()
-    ver = ver.split('.')
-    assert ver[0] in ['4', '5']
+    ver = ver.split(".")
+    assert ver[0] in ["4", "5"]
 
 
 @pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
@@ -29,14 +30,14 @@ def test_outputtype_to_ext():
         assert res == ext
 
     with pytest.raises(KeyError):
-        fsl.Info.output_type_to_ext('JUNK')
+        fsl.Info.output_type_to_ext("JUNK")
 
 
 @pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
 def test_FSLCommand():
     # Most methods in FSLCommand are tested in the subclasses.  Only
     # testing the one item that is not.
-    cmd = fsl.FSLCommand(command='ls')
+    cmd = fsl.FSLCommand(command="ls")
     res = cmd.run()
     assert type(res) == InterfaceResult
 
@@ -44,13 +45,13 @@ def test_FSLCommand():
 @pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
 def test_FSLCommand2():
     # Check default output type and environ
-    cmd = fsl.FSLCommand(command='junk')
+    cmd = fsl.FSLCommand(command="junk")
     assert cmd._output_type == fsl.Info.output_type()
-    assert cmd.inputs.environ['FSLOUTPUTTYPE'] == cmd._output_type
+    assert cmd.inputs.environ["FSLOUTPUTTYPE"] == cmd._output_type
     assert cmd._output_type in fsl.Info.ftypes
 
     cmd = fsl.FSLCommand
-    cmdinst = fsl.FSLCommand(command='junk')
+    cmdinst = fsl.FSLCommand(command="junk")
     for out_type in fsl.Info.ftypes:
         cmd.set_default_output_type(out_type)
         assert cmd._output_type == out_type
@@ -60,21 +61,28 @@ def test_FSLCommand2():
 
 
 @pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
-@pytest.mark.parametrize("args, desired_name",
-                         [({},   {"file": 'foo.nii.gz'}), # just the filename
-                          ({"suffix": '_brain'}, {"file": 'foo_brain.nii.gz'}), # filename with suffix
-                          ({"suffix": '_brain', "cwd": '/data'},
-                           {"dir": '/data', "file": 'foo_brain.nii.gz'}), # filename with suffix and working directory
-                          ({"suffix": '_brain.mat', "change_ext": False}, {"file": 'foo_brain.mat'}) # filename with suffix and no file extension change
-                          ])
+@pytest.mark.parametrize(
+    "args, desired_name",
+    [
+        ({}, {"file": "foo.nii.gz"}),  # just the filename
+        # filename with suffix
+        ({"suffix": "_brain"}, {"file": "foo_brain.nii.gz"}),
+        (
+            {"suffix": "_brain", "cwd": "/data"},
+            # filename with suffix and working directory
+            {"dir": "/data", "file": "foo_brain.nii.gz"},
+        ),
+        # filename with suffix and no file extension change
+        ({"suffix": "_brain.mat", "change_ext": False}, {"file": "foo_brain.mat"}),
+    ],
+)
 def test_gen_fname(args, desired_name):
     # Test _gen_fname method of FSLCommand
-    cmd = fsl.FSLCommand(command='junk', output_type='NIFTI_GZ')
+    cmd = fsl.FSLCommand(command="junk", output_type="NIFTI_GZ")
     pth = os.getcwd()
-    fname = cmd._gen_fname('foo.nii.gz', **args)
+    fname = cmd._gen_fname("foo.nii.gz", **args)
     if "dir" in desired_name.keys():
         desired = os.path.join(desired_name["dir"], desired_name["file"])
     else:
         desired = os.path.join(pth, desired_name["file"])
     assert fname == desired
-
