@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from builtins import open
-
 import os
 
 import pytest
@@ -15,14 +12,18 @@ from nipype.interfaces.fsl import no_fsl
 def test_MultipleRegressDesign(tmpdir):
     tmpdir.chdir()
     foo = fsl.MultipleRegressDesign()
-    foo.inputs.regressors = dict(voice_stenght=[1, 1, 1], age=[0.2, 0.4, 0.5], BMI=[1, -1, 2])
-    con1 = ['voice_and_age', 'T', ['age', 'voice_stenght'], [0.5, 0.5]]
-    con2 = ['just_BMI', 'T', ['BMI'], [1]]
-    foo.inputs.contrasts = [con1, con2, ['con3', 'F', [con1, con2]]]
+    foo.inputs.regressors = dict(
+        voice_stenght=[1, 1, 1], age=[0.2, 0.4, 0.5], BMI=[1, -1, 2]
+    )
+    con1 = ["voice_and_age", "T", ["age", "voice_stenght"], [0.5, 0.5]]
+    con2 = ["just_BMI", "T", ["BMI"], [1]]
+    foo.inputs.contrasts = [con1, con2, ["con3", "F", [con1, con2]]]
     res = foo.run()
 
     for ii in ["mat", "con", "fts", "grp"]:
-        assert getattr(res.outputs, "design_"+ii) == tmpdir.join('design.'+ii).strpath
+        assert (
+            getattr(res.outputs, "design_" + ii) == tmpdir.join("design." + ii).strpath
+        )
 
     design_mat_expected_content = """/NumWaves       3
 /NumPoints      3
@@ -62,6 +63,6 @@ def test_MultipleRegressDesign(tmpdir):
 1
 """
     for ii in ["mat", "con", "fts", "grp"]:
-        assert tmpdir.join('design.'+ii).read() == eval("design_"+ii+"_expected_content")
-
-
+        assert tmpdir.join("design." + ii).read() == eval(
+            "design_" + ii + "_expected_content"
+        )
